@@ -16,7 +16,7 @@ class WebPage():
         
         # Set Defaults
         if icon == None:
-            urllib.request.urlretrieve('https://raw.githubusercontent.com/TomTheCodingGuy/alienHTML/main/src/alien_hurt.ico',"alien_hurt.ico")
+            urllib.request.urlretrieve('https://raw.githubusercontent.com/TomTheCodingGuy/alienHTML/main/alien_hurt.ico',"alien_hurt.ico")
             self.icon = Image.open("alien_hurt.ico")
         else:
             self.icon = icon
