@@ -3,6 +3,8 @@
 ##########################
 
 import unittest
+import urllib
+from PIL import Image
 from alienHTML import WebPage
 
 class WebPageError(Exception):
@@ -19,6 +21,9 @@ class TestWebPage(unittest.TestCase):
         self.assertEqual(self.mypage.action, "w")
         self.assertEqual(self.mypage.tabhead, "HTML with Python!")
         self.assertEqual(self.mypage.bgcolour, "background-color:powderblue")
+        
+        urllib.request.urlretrieve('https://raw.githubusercontent.com/TomTheCodingGuy/alienHTML/main/alien_hurt.ico',"alien_hurt.ico")
+        self.assertEqual(self.mypage.icon, Image.open("alien_hurt.ico"))
     
     def test_showfile(self):
         __openfile = open("./test.html","rt")
@@ -29,5 +34,7 @@ class TestWebPage(unittest.TestCase):
 def cleanup():
     import os
     os.remove("./test.html")
+    if os.path.exists("./alien_hurt.ico"):
+        os.remove("./alien_hurt.ico")
     
 unittest.main()
\ No newline at end of file
